<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CCanvas</name>
    <message>
        <location filename="../canvas/CCanvas.cpp" line="80"/>
        <source>No map view available.</source>
        <translation>Nessuna Vista disponibile.</translation>
    </message>
</context>
<context>
    <name>CCommandProcessor</name>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="30"/>
        <source>Print debug output to console.</source>
        <translation>Stampa l&apos;output di debug sulla console.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="33"/>
        <source>Print debug output to logfile (temp. path).</source>
        <translation>Stampa l&apos;output di debug nel file di log (cartella temp).</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="36"/>
        <source>Do not show splash screen.</source>
        <translation>Non mostrare la schermata iniziale.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>QMapTool application locale.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>File with QMapTool configuration.</source>
        <translation>File con configurazione QMapTool.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>file</source>
        <translation>file</translation>
    </message>
</context>
<context>
    <name>CDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="35"/>
        <source>bad coordinate</source>
        <translation>coordinate errate</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <source>Bad value for X pixel.</source>
        <translation>Valore errato per X pixel.</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Bad value for Y pixel.</source>
        <translation>Valore errato per Y pixel.</translation>
    </message>
</context>
<context>
    <name>CDrawContextPixel</name>
    <message>
        <location filename="../canvas/CDrawContextPixel.cpp" line="63"/>
        <source>Failed to load</source>
        <translation>Caricamento fallito</translation>
    </message>
</context>
<context>
    <name>CDrawContextProj</name>
    <message>
        <location filename="../canvas/CDrawContextProj.cpp" line="59"/>
        <source>Failed to load</source>
        <translation>Caricamento fallito</translation>
    </message>
</context>
<context>
    <name>CGdalFile</name>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>Error...</source>
        <translation>Errore...</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <source>Failed to load file: %1</source>
        <translation>Caricamento del file non riuscito: %1</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>File must be 8 bit palette or gray indexed.</source>
        <translation>Il file deve essere una tavolozza a 8 bit o indicizzato in grigio.</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="170"/>
        <source>(color table)</source>
        <translation>(tabella dei colori)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="174"/>
        <source>(RGB)</source>
        <translation>(RGB)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="178"/>
        <source>(RGBA)</source>
        <translation>(RGBA)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="182"/>
        <source>(unknown)</source>
        <translation>(sconosciuto)</translation>
    </message>
</context>
<context>
    <name>CGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="33"/>
        <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
        <translation>Seleziona uno degli angoli e posiziona il marcatore sul corrispondente incrocio della griglia sulla mappa. Tutti e 4 gli angoli devono essere posizionati.</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="133"/>
        <source>Point 1 - not set</source>
        <translation>Punto 1 - non impostato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="135"/>
        <source>Point 1 - ok</source>
        <translation>Punto 1 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="139"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="143"/>
        <source>Point 1 - bad</source>
        <translation>Punto 1 - errato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="151"/>
        <source>Point 2 - ok</source>
        <translation>Punto 2 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="155"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="159"/>
        <source>Point 2 - bad</source>
        <translation>Punto 2 - errato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="167"/>
        <source>Point 3 - ok</source>
        <translation>Punto 3 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="171"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="175"/>
        <source>Point 3 - bad</source>
        <translation>Punto 3 - errato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="183"/>
        <source>Point 4 - ok</source>
        <translation>Punto 4 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="187"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="191"/>
        <source>Point 4 - bad</source>
        <translation>Punto 4 - errato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="149"/>
        <source>Point 2 - not set</source>
        <translation>Punto 2 - non impostato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="165"/>
        <source>Point 3 - not set</source>
        <translation>Punto 3 - non impostato</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
        <source>Point 4 - not set</source>
        <translation>Punto 4 - non impostato</translation>
    </message>
</context>
<context>
    <name>CGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/CGridSelArea.cpp" line="30"/>
        <source>Select the area to be covered by the calculated reference points. Simply grab the corners of the selection rectangle with a left click and place them where you want with a second click.</source>
        <translation>Seleziona l&apos;area da coprire con i punti di riferimento calcolati. Basta afferrare gli angoli del rettangolo di selezione con un clic sinistro e posizionarli dove si desidera con un secondo clic.</translation>
    </message>
</context>
<context>
    <name>CGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/CGridSetRef.cpp" line="37"/>
        <source>Valid coordinate formats: If the projection is lat/lon all values have to be in degree, e.g. &quot;48.2&quot; or &quot;12.4&quot;. For all other projections values are either in multiple of meter or feet. If you are doing it wrong the entry field will turn red.</source>
        <translation>Formati di coordinate validi: se la proiezione è lat/lon tutti i valori devono essere in gradi, ad es. &quot;48.2&quot; o &quot;12.4&quot;. Per tutte le altre proiezioni, i valori sono in multipli di metro o piedi. Se stai sbagliando, il campo di immissione diventerà rosso.</translation>
    </message>
</context>
<context>
    <name>CHelp</name>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="42"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="80"/>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="81"/>
        <source>Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="82"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CHelpIndex</name>
    <message>
        <location filename="../../common/help/CHelpIndex.cpp" line="26"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CHelpSearch</name>
    <message>
        <location filename="../../common/help/CHelpSearch.cpp" line="30"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CItemListWidget</name>
    <message>
        <location filename="../items/CItemListWidget.cpp" line="86"/>
        <source>Select files...</source>
        <translation>Selezionare i file...</translation>
    </message>
</context>
<context>
    <name>CItemMapLayer</name>
    <message>
        <location filename="../items/CItemMapLayer.cpp" line="33"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
</context>
<context>
    <name>CItemTreeWidget</name>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="133"/>
        <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
        <translation>&lt;p&gt;La mappa attuale &lt;i&gt;&apos;%1&apos;&lt;/i&gt; non corrisponde alla proiezione delle mappe caricate in precedenza. Tutti i file delle mappe devono avere la stessa proiezione.&lt;/p&gt;&lt;p&gt;&lt;b&gt;Questo file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="139"/>
        <source>Error...</source>
        <translation>Errore...</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="199"/>
        <source>Select files...</source>
        <translation>Selezionare i file...</translation>
    </message>
</context>
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../misc.h" line="29"/>
        <source>File access failed...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc.h" line="30"/>
        <source>Failed to open %1 with error %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayCutMap</name>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Delete mask...</source>
        <translation>Cancella maschera...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Are you sure to delete complete mask?</source>
        <translation>Eliminare la maschera completa?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="214"/>
        <source>Save mask...</source>
        <translation>Salva maschera...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="257"/>
        <source>Load mask...</source>
        <translation>Apri maschera...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Failed...</source>
        <translation>Fallito...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Not a shape file.</source>
        <translation>Shape file non valido.</translation>
    </message>
</context>
<context>
    <name>COverlayGridTool</name>
    <message>
        <location filename="../overlay/COverlayGridTool.cpp" line="33"/>
        <source>Before you proceed with &apos;ok&apos;:
Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.

The next step will be to use the Reference Tool to adjust the position of all reference points to the real grid position on the map.</source>
        <translation>Prima di procedere con &apos;ok&apos;:
Si prega di controllare nuovamente tutti i dati. Una coordinata di riferimento errata rovinerà tutto il lavoro. Controllare anche se l&apos;area selezionata contiene più punti di riferimento possibili al confine. Puoi eliminare facilmente i punti all&apos;esterno della mappa nello Strumento di riferimento. Ma è molto più difficile stabilire punti aggiuntivi nel caso in cui tu ne perda qualcuno. Al termine, premere &apos;ok&apos; per trasferire i punti di riferimento derivati nello strumento di riferimento.

Il prossimo passo sarà utilizzare lo strumento di riferimento per regolare la posizione di tutti i punti di riferimento sulla posizione della griglia reale sulla mappa.</translation>
    </message>
</context>
<context>
    <name>COverlayRefMap</name>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="43"/>
        <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
        <translation>Se hai utilizzato lo strumento griglia, devi mettere a punto i punti di riferimento posizionandoli il più possibile sull&apos;incrocio della griglia. Tieni presente che se superi la scala ottieni punti di salto arrotondando gli effetti. Sii preciso ma non esagerare.
Se lo stato attivo del mouse è sulla mappa, è possibile utilizzare i tasti N e B per spostarsi avanti e indietro nell&apos;elenco dei punti di riferimento.
C&apos;è anche l&apos;opzione per mettere a punto i punti di riferimento in modalità automatica. In questa modalità il punto di riferimento successivo viene selezionato automaticamente subito dopo aver posizionato quello corrente. Questo è molto conveniente per un gran numero di punti di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="519"/>
        <source>Save reference points...</source>
        <translation>Salva i punti di riferimento...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="554"/>
        <source>Load reference points...</source>
        <translation>Carica punti di riferimento...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="589"/>
        <source>Delete all reference points...</source>
        <translation>Cancella tutti i punti di riferimento...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="590"/>
        <source>Are you sure to delete all reference points in the list?</source>
        <translation>Sei sicuro di voler cancellare tutti i punti di riferimento inseriti?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete...</source>
        <translation>Cancella...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete all selected reference points?</source>
        <translation>Cancellare tutti i punti sezionati?</translation>
    </message>
</context>
<context>
    <name>COverlayRefMapPoint</name>
    <message>
        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="40"/>
        <source>bad coordinate</source>
        <translation>coordinate errate</translation>
    </message>
</context>
<context>
    <name>CProj</name>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="153"/>
        <source>The value
&apos;%1&apos;
is not a valid coordinate system definition:
%2</source>
        <translation type="unfinished">Il valore
&apos;%1&apos;
non è una definizione valida nel sistema di coordinate:
%2</translation>
    </message>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="162"/>
        <source>Lat/Lon projection is not allowed in this case.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CProjWizard</name>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="45"/>
        <source> (Spheroid: %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="59"/>
        <source>north</source>
        <translation>nord</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="60"/>
        <source>south</source>
        <translation>sud</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="199"/>
        <source>Error...</source>
        <translation>Errore...</translation>
    </message>
</context>
<context>
    <name>CSetupExtTools</name>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="61"/>
        <location filename="../setup/CSetupExtTools.cpp" line="62"/>
        <location filename="../setup/CSetupExtTools.cpp" line="63"/>
        <location filename="../setup/CSetupExtTools.cpp" line="64"/>
        <location filename="../setup/CSetupExtTools.cpp" line="65"/>
        <location filename="../setup/CSetupExtTools.cpp" line="66"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="77"/>
        <source>Select %1 binary...</source>
        <translation>Selezione %1 binario...</translation>
    </message>
</context>
<context>
    <name>CShell</name>
    <message>
        <location filename="../shell/CShell.cpp" line="40"/>
        <source>Execution of external program `%1` failed: </source>
        <translation>Esecuzione del programma esterno `%1` non riuscita: </translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="43"/>
        <source>Process cannot be started.
</source>
        <translation>Il processo non può essere avviato.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="44"/>
        <source>Make sure the required packages are installed, `%1` exists and is executable.
</source>
        <translation>Assicurarsi che i pacchetti richiesti siano installati, che esista, &apos;%1&apos; e sia eseguibile.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="49"/>
        <source>External process crashed.
</source>
        <translation>Processo esterno bloccato.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="53"/>
        <source>An unknown error occurred.
</source>
        <translation>Si è verificato un errore sconosciuto.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="130"/>
        <source>!!! failed !!!
</source>
        <translation>!!! fallimento !!!
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="143"/>
        <source>
Canceled by user&apos;s request.
</source>
        <translation>
Annullato su richiesta dell&apos;utente.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="168"/>
        <source>!!! done !!!
</source>
        <translation>!!! fine !!!
</translation>
    </message>
</context>
<context>
    <name>CToolAddOverview</name>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="29"/>
        <source>Add Overviews</source>
        <translation>Aggiungi panoramiche</translation>
    </message>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="32"/>
        <source>Raster map files consume quite some memory if a larger area is displayed. Pre-calculated overview levels help to speed up loading and displaying the map. These overviews can be stored within the map file as well as an external file. GDAL can remove internally stored overviews, however it will not free the used space in the file. Therefore it&apos;s size will remain large. If you do not like that use the external option.</source>
        <translation>I file delle mappe raster consumano abbastanza memoria se viene visualizzata un&apos;area più grande. I livelli di panoramica pre-calcolati aiutano ad accelerare il caricamento e la visualizzazione della mappa. Queste panoramiche possono essere archiviate nel file della mappa e in un file esterno. GDAL può rimuovere panoramiche archiviate internamente, tuttavia non libererà lo spazio utilizzato nel file. Pertanto le sue dimensioni rimarranno grandi. Se non ti piace, usa l&apos;opzione esterna.</translation>
    </message>
</context>
<context>
    <name>CToolCutMap</name>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="29"/>
        <source>Cut Map</source>
        <translation>Ritaglia mappa</translation>
    </message>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="32"/>
        <source>Paper maps usually have a border you don&apos;t want to have. To combine maps seamlessly you have to cut that border, replacing it by transparent pixel. This tool allows you to define a cut line and it will add an alpha channel for transparency to your map.</source>
        <translation>Le mappe cartacee di solito hanno un bordo che non si desidera avere. Per combinare perfettamente le mappe devi tagliare quel bordo, sostituendolo con pixel trasparenti. Questo strumento ti consente di definire una linea di taglio e aggiungerà un canale alfa per la trasparenza alla tua mappa.</translation>
    </message>
</context>
<context>
    <name>CToolExport</name>
    <message>
        <location filename="../tool/CToolExport.cpp" line="29"/>
        <source>Export Maps</source>
        <translation>Esporta mappa</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="33"/>
        <source>To use the maps on your device you have to export them to the proprietary format supported by the device. Depending on the device this can vary from a single layer map to a map stack with maps of different scale.</source>
        <translation>Per usare le mappe sul tuo dispositivo devi esportarle nel formato proprietario supportato dal dispositivo. A seconda del dispositivo, ciò può variare da una mappa a singolo layer a una pila di mappe con mappe di diversa scala.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="41"/>
        <source>Note: This tool will use all files in the list as a input. This will only work if all files have the same projection.</source>
        <translation>Nota: questo strumento utilizzerà tutti i file nell&apos;elenco come input. Funzionerà solo se tutti i file hanno la stessa proiezione.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="104"/>
        <source>Select filename...</source>
        <translation>Scegli un nome per il file...</translation>
    </message>
</context>
<context>
    <name>CToolGrid</name>
    <message>
        <location filename="../tool/CToolGrid.cpp" line="35"/>
        <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
        <translation>Posizionando 4 punti di riferimento agli angoli di un quadrato della griglia e facendo riferimento a loro per il loro angolo in alto a sinistra, la larghezza e l&apos;altezza, è possibile stimare tutti gli altri punti della griglia.</translation>
    </message>
</context>
<context>
    <name>CToolPalettize</name>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="30"/>
        <source>Add Color Palette</source>
        <translation>Aggiungi tavolozza colori</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="37"/>
        <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
        <translation>Di solito si utilizza il colore RGBA mentre si fa riferimento a una mappa perché l&apos;ampio spazio colore consente di ridimensionare e ruotare la mappa senza perdita di qualità. Ma ilrisultato è un file piuttosto grande. La dimensione del file può essere ottimizzata utilizzando una tavolozza di colori anziché lo spazio colore RGBA. L&apos;impatto sulla qualità è basso finché non si desidera ridimensionare o ruotare la mappa. Se si desidera combinare i file con una tavolozza di colori, tutti i file devono avere la stessa tavolozza.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="49"/>
        <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
        <translation>Nota: questo strumento utilizzerà tutti i file nell&apos;elenco come input combinato per derivare una tavolozza ottimale. Funzionerà solo se tutti i file hanno la stessa proiezione e scala.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="114"/>
        <source>Select filename...</source>
        <translation>Scegli un nome per il file...</translation>
    </message>
</context>
<context>
    <name>CToolRefMap</name>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="32"/>
        <source>Reference Map</source>
        <translation>Mappa di riferimento</translation>
    </message>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="35"/>
        <source>A scan of a paper map can be converted to a referenced raster map if you place at least three reference points on the map. The more points the better the result. If your map has a grid you can place points on that grid with the grid tool.</source>
        <translation>La scansione di una mappa cartacea può essere convertita in una mappa raster referenziata se si posizionano almeno tre punti di riferimento sulla mappa. Con più punti il risultato è migliore. Se la tua mappa ha una griglia puoi posizionare punti su quella griglia con lo strumento griglia.</translation>
    </message>
</context>
<context>
    <name>IAbout</name>
    <message>
        <location filename="../IAbout.ui" line="14"/>
        <source>About...</source>
        <translation>Ringraziamenti...</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="26"/>
        <source>&lt;b&gt;QMapTool&lt;/b&gt;, Version</source>
        <translation>&lt;b&gt;QMapTool&lt;/b&gt;, Versione</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="39"/>
        <location filename="../IAbout.ui" line="77"/>
        <location filename="../IAbout.ui" line="91"/>
        <location filename="../IAbout.ui" line="105"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="70"/>
        <source>Qt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="84"/>
        <source>GDAL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="98"/>
        <source>PROJ</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="121"/>
        <source>This software is licensed under GPL3 or any later version</source>
        <translation>Questo software è concesso in licenza in GPL3 o versioni successive</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="128"/>
        <source>© 2017 Oliver Eichler (oliver.eichler@gmx.de)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ICoordFormatSetup</name>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="14"/>
        <source>Coordinate Format...</source>
        <translation>Formato coordinate...</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="24"/>
        <source>N48° 53&apos; 39.6&quot; E13° 31&apos; 6.78&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="31"/>
        <source>N48.8943° E013.51855°</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="38"/>
        <source>N48° 53.660 E013° 31.113</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Per alcuni elementi della GUI la modifica delle unità non avrà effetto fino al riavvio di QMapTool.</translation>
    </message>
</context>
<context>
    <name>IDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="25"/>
        <source>Coord. Map File [pixel]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="32"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="42"/>
        <source>y</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="49"/>
        <source>Coord. lat/lon WGS84 [°]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="59"/>
        <source>Bad position format. Must be: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
or
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation>Formato di posizione errato. Deve essere: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
o
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</translation>
    </message>
</context>
<context>
    <name>IGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="150"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="224"/>
        <source>Set Area</source>
        <translation>Imposta area</translation>
    </message>
</context>
<context>
    <name>IGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="35"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="35"/>
        <source>Grid Projection:</source>
        <translation>Proiezione della griglia:</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="47"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="60"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="72"/>
        <source>Easting</source>
        <translation>Verso est</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="82"/>
        <source>Horiz. Spacing</source>
        <translation>Spazio orizzontale</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="92"/>
        <source>Northing</source>
        <translation>Verso nord</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="102"/>
        <source>Vert. Spacing</source>
        <translation>Spazio verticale</translation>
    </message>
</context>
<context>
    <name>IItemListWidget</name>
    <message>
        <location filename="../items/IItemListWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Aggiungi i file della mappa all&apos;elenco</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="43"/>
        <location filename="../items/IItemListWidget.ui" line="60"/>
        <location filename="../items/IItemListWidget.ui" line="77"/>
        <location filename="../items/IItemListWidget.ui" line="94"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Rimuovi il file selezionato dall&apos;elenco.</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Cancella l&apos;elenco completo dei file della mappa.</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Ricarica la mappa attualmente selezionata.</translation>
    </message>
</context>
<context>
    <name>IItemTreeWidget</name>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Aggiungi i file della mappa all&apos;elenco</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="43"/>
        <location filename="../items/IItemTreeWidget.ui" line="60"/>
        <location filename="../items/IItemTreeWidget.ui" line="77"/>
        <location filename="../items/IItemTreeWidget.ui" line="94"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Rimuovi il file selezionato dall&apos;elenco.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Cancella l&apos;elenco completo dei file della mappa.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Ricarica la mappa attualmente selezionata.</translation>
    </message>
</context>
<context>
    <name>IMainWindow</name>
    <message>
        <location filename="../IMainWindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="32"/>
        <source>Setup</source>
        <translation>Setup</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="41"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="47"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="52"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="68"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="101"/>
        <source>Shell</source>
        <translation>Shell</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="120"/>
        <source>About</source>
        <translation>About</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="129"/>
        <source>Ext. Tools</source>
        <translation>Strum. esterni</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="132"/>
        <source>Setup paths to external tools, like gdalwarp etc.</source>
        <translation>Percorsi di installazione per strumenti esterni, come gdalwarp ecc.</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="144"/>
        <location filename="../IMainWindow.ui" line="147"/>
        <source>Flip Mouse Wheel</source>
        <translation>Gira la rotellina del mouse</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="156"/>
        <location filename="../IMainWindow.ui" line="159"/>
        <source>Setup Units</source>
        <translation>Unità di installazione</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="168"/>
        <source>Setup Coord. Format</source>
        <translation>Imposta formato coordinate</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="171"/>
        <source>Change the format coordinates are displayed</source>
        <translation>Modifica le coordinate nel formato come vengono visualizzate</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="182"/>
        <source>Show Tool Help</source>
        <translation>Mostra l&apos;aiuto</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="191"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="194"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IOverlayCutMap</name>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="35"/>
        <source>Just move the map and zoom.</source>
        <translation>Basta spostare la mappa e ingrandire.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="58"/>
        <source>Add point to mask.</source>
        <translation>Aggiungi un punto alla maschera.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="61"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="84"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="107"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="137"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="158"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="175"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="81"/>
        <source>Move point of mask.</source>
        <translation>Sposta il punto della maschera.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="104"/>
        <source>Remove point from mask.</source>
        <translation>Rimuovere il punto dalla maschera.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="134"/>
        <source>Remove complete cut mask.</source>
        <translation>Rimuovere la maschera di taglio completa.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="155"/>
        <source>Load cut mask from shape file.</source>
        <translation>Carica la maschera tagliata da un shape file.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="172"/>
        <source>Save cut mask to shape file.</source>
        <translation>Salva la maschera come shape file.</translation>
    </message>
</context>
<context>
    <name>IOverlayGridTool</name>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="145"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IOverlayRefMap</name>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="40"/>
        <source>Just move the map and zoom.</source>
        <translation>Basta spostare la mappa e ingrandire.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="63"/>
        <source>Add reference point.</source>
        <translation>Aggiungi punto di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="66"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="89"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="112"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="135"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="165"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="179"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="200"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="217"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="244"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="326"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="86"/>
        <source>Move reference point.</source>
        <translation>Muovi il punto di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="109"/>
        <source>Remove single reference point.</source>
        <translation>Rimuovi singolo punto di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="132"/>
        <source>Move reference points with auto mode. This will pickup the next point after you moved a reference point.</source>
        <translation>Sposta i punti di riferimento con la modalità automatica. Questo riprenderà il punto successivo dopo aver spostato un punto di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="162"/>
        <source>Remove all reference points.</source>
        <translation>Cancella tutti i punti di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="176"/>
        <source>Switch to the Grid Tool.</source>
        <translation>Passa allo strumento griglia.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="197"/>
        <source>Load reference points from GCP file.</source>
        <translation>Carica punti di riferimento dal file GCP.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="214"/>
        <source>Save reference points into GCP file.</source>
        <translation>Salva i punti di riferimento nel file GCP.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="241"/>
        <source>Sort list of reference points.</source>
        <translation>Ordina l&apos;elenco dei punti di riferimento.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="281"/>
        <source>(x, y)[pixel]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="286"/>
        <source>(lat, lon)[°]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="294"/>
        <source>TextLabel</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="304"/>
        <source>Final Map Projection:</source>
        <translation>Proiezione finale della mappa:</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="316"/>
        <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;EPSG:...&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="323"/>
        <source>Start projection wizard.</source>
        <translation>Avvia la procedura guidata di proiezione.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="343"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>IProjWizard</name>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
        <source>PROJ Wizard</source>
        <translation>Procedura guidata PROJ</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="29"/>
        <source>Mercator</source>
        <translation>Mercatore</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="38"/>
        <source>UTM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="45"/>
        <source>zone</source>
        <translation>zona</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="82"/>
        <source>user defined</source>
        <translation>Definito dall&apos;utente</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="94"/>
        <source>Datum</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="104"/>
        <source>World Mercator (OSM)</source>
        <translation>World Mercator (OSM)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="124"/>
        <source>Result:</source>
        <translation>Risultato:</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="138"/>
        <source>UPS North (North Pole)</source>
        <translation>UPS Nord (Polo Nord)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="145"/>
        <source>UPS South (South Pole)</source>
        <translation>UPS Sud (Polo Sud)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="152"/>
        <source>Projection</source>
        <translation>Proiezione</translation>
    </message>
</context>
<context>
    <name>ISetupExtTools</name>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="14"/>
        <source>Setup Ext. Tools</source>
        <translation>Setup strumenti esterni</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="22"/>
        <location filename="../setup/ISetupExtTools.ui" line="64"/>
        <location filename="../setup/ISetupExtTools.ui" line="99"/>
        <location filename="../setup/ISetupExtTools.ui" line="173"/>
        <location filename="../setup/ISetupExtTools.ui" line="194"/>
        <location filename="../setup/ISetupExtTools.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;non trovato&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="32"/>
        <location filename="../setup/ISetupExtTools.ui" line="53"/>
        <location filename="../setup/ISetupExtTools.ui" line="74"/>
        <location filename="../setup/ISetupExtTools.ui" line="88"/>
        <location filename="../setup/ISetupExtTools.ui" line="135"/>
        <location filename="../setup/ISetupExtTools.ui" line="149"/>
        <location filename="../setup/ISetupExtTools.ui" line="183"/>
        <location filename="../setup/ISetupExtTools.ui" line="211"/>
        <location filename="../setup/ISetupExtTools.ui" line="225"/>
        <location filename="../setup/ISetupExtTools.ui" line="239"/>
        <location filename="../setup/ISetupExtTools.ui" line="264"/>
        <location filename="../setup/ISetupExtTools.ui" line="275"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="112"/>
        <source>gdal_translate:</source>
        <translation>gdal_translate:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="43"/>
        <source>gdalbuildvrt</source>
        <translation>gdalbuildvrt:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="166"/>
        <source>gdaladdo:</source>
        <translation>gdaladdo:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="125"/>
        <source>gdalwarp:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="29"/>
        <location filename="../setup/ISetupExtTools.ui" line="132"/>
        <location filename="../setup/ISetupExtTools.ui" line="180"/>
        <location filename="../setup/ISetupExtTools.ui" line="208"/>
        <location filename="../setup/ISetupExtTools.ui" line="222"/>
        <source>Setup user defined path.</source>
        <translation>Imposta il percorso.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="201"/>
        <source>qmt_rgb2pct</source>
        <translation>qmt_rgb2pct:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="50"/>
        <location filename="../setup/ISetupExtTools.ui" line="71"/>
        <location filename="../setup/ISetupExtTools.ui" line="85"/>
        <location filename="../setup/ISetupExtTools.ui" line="146"/>
        <location filename="../setup/ISetupExtTools.ui" line="236"/>
        <source>Reset user defined path setup.</source>
        <translation>Reset percorso.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="250"/>
        <source>qmt_map2jnx</source>
        <translation>qmt_map2jnx:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="288"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Usually QMapTool should detect all external tools by itself. If it does not, it&apos;s a bad setup and you should fix the PATH variable of your system. You can setup the paths manually, too, if you know what you are doing. But please keep in mind that GDAL needs a proper environment setup to function properly. If it&apos;s not setup properly you might get results but these can be off grid.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Di solito QMapTool dovrebbe rilevare tutti gli strumenti esterni da solo. In caso contrario, è una configurazione errata e dovresti correggere la variabile PATH del tuo sistema. Puoi anche impostare i percorsi manualmente, se sai cosa stai facendo. Ma tieni presente che GDAL ha bisogno di una corretta configurazione dell&apos;ambiente per funzionare correttamente. Se non è configurato correttamente, potresti ottenere dei risultati ma questi possono essere inutili.</translation>
    </message>
</context>
<context>
    <name>ITimeZoneSetup</name>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="14"/>
        <source>Setup Timezone ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="22"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="32"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="42"/>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="75"/>
        <source>Print date/time in </source>
        <translation>Stampo data/ora in </translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="82"/>
        <source>long format, or</source>
        <translation>Formato lungo</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="92"/>
        <source>short format</source>
        <translation>Formato breve</translation>
    </message>
</context>
<context>
    <name>IToolAddOverview</name>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="119"/>
        <source>:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="126"/>
        <source>:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="133"/>
        <source>:8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="140"/>
        <source>:16</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="147"/>
        <source>:32</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="154"/>
        <source>:64</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="164"/>
        <source>Remove all overview levels from map file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="167"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="174"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="177"/>
        <source>Overview as external file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="207"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="221"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="232"/>
        <source>For all files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolCutMap</name>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="114"/>
        <source>Output filename suffix</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="133"/>
        <source>_cut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="148"/>
        <source>Create overviews for result.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="155"/>
        <source>GDAL Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="183"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="197"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="208"/>
        <source>For all files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="233"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="243"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolExport</name>
    <message>
        <location filename="../tool/IToolExport.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="59"/>
        <location filename="../tool/IToolExport.ui" line="72"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="83"/>
        <source>Garmin BirdsEye (*.jnx)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="88"/>
        <source>TwoNav Raster (*.rmap)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="101"/>
        <source>not implemented yet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="112"/>
        <source>Target File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="130"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="144"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="173"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_map2jnx&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="184"/>
        <source>Target Filename</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolExportJnx</name>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="14"/>
        <source>Form</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="35"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="81"/>
        <source>BirdsEye</source>
        <translation>BirdsEye</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="50"/>
        <source>Product ID</source>
        <translation>Product ID</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="57"/>
        <source>Copyright notice</source>
        <translation>Copyright notice</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="64"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="95"/>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="71"/>
        <source>Product name</source>
        <translation>Product name</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="88"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="105"/>
        <source>JPEG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="133"/>
        <source>Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="140"/>
        <source>Chroma subsampling</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="148"/>
        <source>411</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="153"/>
        <source>422</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="158"/>
        <source>444</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="169"/>
        <source>Device</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="184"/>
        <source>Z-Order</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolGDALGroupBox</name>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="17"/>
        <source>GDAL Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="50"/>
        <source>Resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="84"/>
        <source>Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="118"/>
        <source>Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="144"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="188"/>
        <source>Other:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IToolGrid</name>
    <message>
        <location filename="../tool/IToolGrid.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="56"/>
        <source>Grid Tool</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="65"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="99"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="110"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="134"/>
        <source>Reset</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolOverviewGroupBox</name>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="71"/>
        <source>:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="78"/>
        <source>:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="85"/>
        <source>:8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="92"/>
        <source>:16</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="99"/>
        <source>:32</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="106"/>
        <source>:64</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="119"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="122"/>
        <source>Overview as external file</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolPalettize</name>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="65"/>
        <location filename="../tool/IToolPalettize.ui" line="78"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="96"/>
        <source>Single files, filename suffix</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="109"/>
        <source>_8bit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="123"/>
        <source>Combined file, filename:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="135"/>
        <source>Embed result into *.vrt file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="142"/>
        <source>Create overviews for result.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="149"/>
        <source>GDAL Parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="177"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="191"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="220"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="230"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="240"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_rgb2pct&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="254"/>
        <source>Select filename</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IToolRefMap</name>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="113"/>
        <source>Output filename suffix</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="132"/>
        <source>_ref</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="144"/>
        <source>Embed result into *.vrt file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="151"/>
        <source>Create overviews for result.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="158"/>
        <source>GDAL Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="186"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="200"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="211"/>
        <source>For all files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="236"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="246"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="256"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IUnit</name>
    <message>
        <location filename="../units/IUnit.cpp" line="714"/>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="715"/>
        <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Position values out of bounds. </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IUnitsSetup</name>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="14"/>
        <source>Setup units...</source>
        <translation>Imposta unità...</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="24"/>
        <source>Nautical</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="31"/>
        <source>Imperial</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="38"/>
        <source>Metric</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Per alcuni elementi della GUI la modifica delle unità non avrà effetto fino al riavvio di QMapTool.</translation>
    </message>
</context>
</TS>
